@@ -18,7 +18,7 @@ for FILE in test/integration/suites/k8s*; do
         job_set[$current_runner]+="${FILE##test/integration/} "
 
         ((current_runner++))
-        if [ $current_runner -gt "$NUM_RUNNERS" ]; then
+        if [ "$current_runner" -gt "$NUM_RUNNERS" ]; then
                 current_runner=1
         fi
 done
