@@ -71,6 +71,7 @@ type agentConfig struct {
 	RebootstrapMode               string    `hcl:"rebootstrap_mode"`
 	RebootstrapDelay              string    `hcl:"rebootstrap_delay"`
 	JoinToken                     string    `hcl:"join_token"`
+	JoinTokenFile                 string    `hcl:"join_token_file"`
 	LogFile                       string    `hcl:"log_file"`
 	LogFormat                     string    `hcl:"log_format"`
 	LogLevel                      string    `hcl:"log_level"`
@@ -224,6 +225,11 @@ func (c *agentConfig) validate() error {
 		return errors.New("agent section must be configured")
 	}
 
+	// Validate join token configuration
+	if c.JoinToken != "" && c.JoinTokenFile != "" {
+		return errors.New("only one of join_token or join_token_file can be specified, not both")
+	}
+
 	if c.ServerAddress == "" {
 		return errors.New("server_address must be configured")
 	}
@@ -336,6 +342,7 @@ func parseFlags(name string, args []string, output io.Writer) (*agentConfig, err
 	flags.StringVar(&c.ConfigPath, "config", defaultConfigPath, "Path to a SPIRE config file")
 	flags.StringVar(&c.DataDir, "dataDir", "", "A directory the agent can use for its runtime data")
 	flags.StringVar(&c.JoinToken, "joinToken", "", "An optional token which has been generated by the SPIRE server")
+	flags.StringVar(&c.JoinTokenFile, "joinTokenFile", "", "Path to a file containing an optional join token which has been generated by the SPIRE server")
 	flags.StringVar(&c.LogFile, "logFile", "", "File to write logs to")
 	flags.StringVar(&c.LogFormat, "logFormat", "", "'text' or 'json'")
 	flags.StringVar(&c.LogLevel, "logLevel", "", "'debug', 'info', 'warn', or 'error'")
@@ -502,7 +509,20 @@ func NewAgentConfig(c *Config, logOptions []log.Option, allowUnknownConfig bool)
 		}
 		ac.AdminBindAddress = adminAddr
 	}
-	ac.JoinToken = c.Agent.JoinToken
+	// Handle join token - read from file if specified
+	if c.Agent.JoinTokenFile != "" {
+		tokenBytes, err := os.ReadFile(c.Agent.JoinTokenFile)
+		if err != nil {
+			return nil, fmt.Errorf("unable to read join token file %q: %w", c.Agent.JoinTokenFile, err)
+		}
+		joinToken := strings.TrimSpace(string(tokenBytes))
+		if joinToken == "" {
+			return nil, errors.New("join token file is empty")
+		}
+		ac.JoinToken = joinToken
+	} else {
+		ac.JoinToken = c.Agent.JoinToken
+	}
 	ac.DataDir = c.Agent.DataDir
 	ac.DefaultSVIDName = c.Agent.SDS.DefaultSVIDName
 	ac.DefaultBundleName = c.Agent.SDS.DefaultBundleName
