@@ -34,6 +34,7 @@ import (
 	"github.com/spiffe/spire/pkg/common/uptime"
 	"github.com/spiffe/spire/pkg/common/util"
 	"github.com/spiffe/spire/pkg/common/version"
+	"github.com/spiffe/spire/pkg/common/x509util"
 	_ "golang.org/x/net/trace" // registers handlers on the DefaultServeMux
 	"google.golang.org/grpc"
 	"google.golang.org/grpc/codes"
@@ -41,12 +42,15 @@ import (
 )
 
 const (
-	bootstrapBackoffInterval       = 5 * time.Second
-	bootstrapBackoffMaxElapsedTime = 1 * time.Minute
+	bootstrapBackoffInterval         = 5 * time.Second
+	bootstrapBackoffMaxElapsedTime   = 1 * time.Minute
+	startHealthChecksTimeout         = 8 * time.Second
+	rebootstrapBackoffMaxElapsedTime = 24 * time.Hour
 )
 
 type Agent struct {
-	c *Config
+	c       *Config
+	started bool
 }
 
 // Run the agent
@@ -66,8 +70,8 @@ func (a *Agent) Run(ctx context.Context) error {
 		return fmt.Errorf("failed to open storage: %w", err)
 	}
 
-	ctx, cancel := context.WithCancel(ctx)
-	defer cancel()
+	ctx, cancel := context.WithCancelCause(ctx)
+	defer cancel(nil)
 
 	if a.c.ProfilingEnabled {
 		stopProfiling := a.setupProfiling(ctx)
@@ -98,6 +102,12 @@ func (a *Agent) Run(ctx context.Context) error {
 	defer cat.Close()
 
 	healthChecker := health.NewChecker(a.c.HealthChecks, a.c.Log)
+	if err := healthChecker.AddCheck("agent", a); err != nil {
+		return fmt.Errorf("failed adding healthcheck: %w", err)
+	}
+
+	taskRunner := util.NewTaskRunner(ctx, cancel)
+	taskRunner.StartTasks(metrics.ListenAndServe)
 
 	nodeAttestor := nodeattestor.JoinToken(a.c.Log, a.c.JoinToken)
 	if a.c.JoinToken == "" {
@@ -106,12 +116,39 @@ func (a *Agent) Run(ctx context.Context) error {
 
 	var as *node_attestor.AttestationResult
 
+	readyForHealthChecks := make(chan struct{})
+	go func() {
+		a.startHealthChecks(readyForHealthChecks, taskRunner, healthChecker)
+	}()
+
+	a.c.TrustBundleSources.SetMetrics(metrics)
+	err = a.c.TrustBundleSources.SetStorage(sto)
+	if err != nil {
+		return err
+	}
+
+	if a.c.RebootstrapMode != RebootstrapNever {
+		_, reattestable, err := sto.LoadSVID()
+		if err == nil && !reattestable {
+			if a.c.RebootstrapMode == RebootstrapAlways {
+				return errors.New("you have requested rebootstrap support but the NodeAttestor plugin or the spire server configuration is not allowing it")
+			} else {
+				a.c.Log.Warn("you have requested rebootstrap support but the NodeAttestor plugin or the spire server configuration is not allowing it. Disabling")
+				a.c.RebootstrapMode = RebootstrapNever
+			}
+		}
+	}
+
 	if a.c.RetryBootstrap {
 		attBackoffClock := clock.New()
+		backoffTime := bootstrapBackoffMaxElapsedTime
+		if a.c.RebootstrapMode != RebootstrapNever {
+			backoffTime = rebootstrapBackoffMaxElapsedTime
+		}
 		attBackoff := backoff.NewBackoff(
 			attBackoffClock,
 			bootstrapBackoffInterval,
-			backoff.WithMaxElapsedTime(bootstrapBackoffMaxElapsedTime),
+			backoff.WithMaxElapsedTime(backoffTime),
 		)
 
 		for {
@@ -123,9 +160,47 @@ func (a *Agent) Run(ctx context.Context) error {
 			if err == nil {
 				as, err = a.attest(ctx, sto, cat, metrics, nodeAttestor, bootstrapTrustBundle, insecureBootstrap)
 				if err == nil {
+					err = a.c.TrustBundleSources.SetSuccess()
+					if err != nil {
+						return err
+					}
+					if a.c.RebootstrapMode != RebootstrapNever {
+						_, reattestable, err := sto.LoadSVID()
+						if err == nil && !reattestable {
+							if a.c.RebootstrapMode == RebootstrapAlways {
+								return errors.New("you have requested rebootstrap support but the NodeAttestor plugin or the spire server configuration is not allowing it")
+							} else {
+								a.c.Log.Warn("you have requested rebootstrap support but the NodeAttestor plugin or the spire server configuration is not allowing it. Disabling")
+								a.c.RebootstrapMode = RebootstrapNever
+							}
+						}
+					}
 					break
 				}
 
+				if x509util.IsUnknownAuthorityError(err) {
+					if a.c.TrustBundleSources.IsBootstrap() {
+						a.c.Log.Info("Trust Bandle and Server dont agree.... bootstrapping again")
+					} else if a.c.RebootstrapMode != RebootstrapNever {
+						startTime, err := a.c.TrustBundleSources.GetStartTime()
+						if err != nil {
+							return nil
+						}
+						seconds := time.Since(startTime)
+						if seconds < a.c.RebootstrapDelay {
+							a.c.Log.WithFields(logrus.Fields{
+								"time left": a.c.RebootstrapDelay - seconds,
+							}).Info("Trust Bandle and Server dont agree.... Ignoring for now.")
+						} else {
+							a.c.Log.Warn("Trust Bandle and Server dont agree.... rebootstrapping")
+							err = sto.StoreBundle(nil)
+							if err != nil {
+								return err
+							}
+						}
+					}
+				}
+
 				if status.Code(err) == codes.PermissionDenied {
 					return err
 				}
@@ -177,19 +252,17 @@ func (a *Agent) Run(ctx context.Context) error {
 		Metrics: metrics,
 	})
 
-	endpoints := a.newEndpoints(metrics, manager, workloadAttestor)
-
-	if err := healthChecker.AddCheck("agent", a); err != nil {
-		return fmt.Errorf("failed adding healthcheck: %w", err)
-	}
+	agentEndpoints := a.newEndpoints(metrics, manager, workloadAttestor)
+	go func() {
+		agentEndpoints.WaitForListening(readyForHealthChecks)
+		a.started = true
+	}()
 
 	tasks := []func(context.Context) error{
 		manager.Run,
 		storeService.Run,
-		endpoints.ListenAndServe,
-		metrics.ListenAndServe,
+		agentEndpoints.ListenAndServe,
 		catalog.ReconfigureTask(a.c.Log.WithField(telemetry.SubsystemName, "reconfigurer"), cat),
-		healthChecker.ListenAndServe,
 	}
 
 	if a.c.AdminBindAddress != nil {
@@ -201,7 +274,8 @@ func (a *Agent) Run(ctx context.Context) error {
 		tasks = append(tasks, a.c.LogReopener)
 	}
 
-	err = util.RunTasks(ctx, tasks...)
+	taskRunner.StartTasks(tasks...)
+	err = taskRunner.Wait()
 	if errors.Is(err, context.Canceled) {
 		err = nil
 	}
@@ -295,6 +369,9 @@ func (a *Agent) newManager(ctx context.Context, sto storage.Storage, cat catalog
 		Metrics:                  metrics,
 		WorkloadKeyType:          a.c.WorkloadKeyType,
 		Storage:                  sto,
+		TrustBundleSources:       a.c.TrustBundleSources,
+		RebootstrapMode:          a.c.RebootstrapMode,
+		RebootstrapDelay:         a.c.RebootstrapDelay,
 		SyncInterval:             a.c.SyncInterval,
 		UseSyncAuthorizedEntries: a.c.UseSyncAuthorizedEntries,
 		X509SVIDCacheMaxSize:     a.c.X509SVIDCacheMaxSize,
@@ -308,17 +385,44 @@ func (a *Agent) newManager(ctx context.Context, sto storage.Storage, cat catalog
 	mgr := manager.New(config)
 	if a.c.RetryBootstrap {
 		initBackoffClock := clock.New()
+		backoffTime := bootstrapBackoffMaxElapsedTime
+		if a.c.RebootstrapMode != RebootstrapNever {
+			backoffTime = rebootstrapBackoffMaxElapsedTime
+		}
 		initBackoff := backoff.NewBackoff(
 			initBackoffClock,
 			bootstrapBackoffInterval,
-			backoff.WithMaxElapsedTime(bootstrapBackoffMaxElapsedTime),
+			backoff.WithMaxElapsedTime(backoffTime),
 		)
 
 		for {
 			err := mgr.Initialize(ctx)
 			if err == nil {
+				err = a.c.TrustBundleSources.SetSuccessIfRunning()
+				if err != nil {
+					return nil, err
+				}
 				return mgr, nil
 			}
+			if x509util.IsUnknownAuthorityError(err) && a.c.RebootstrapMode != RebootstrapNever {
+				startTime, err := a.c.TrustBundleSources.GetStartTime()
+				if err != nil {
+					return nil, err
+				}
+				seconds := time.Since(startTime)
+				if seconds < a.c.RebootstrapDelay {
+					a.c.Log.WithFields(logrus.Fields{
+						"time left": a.c.RebootstrapDelay - seconds,
+					}).Info("Trust Bandle and Server dont agree.... Ignoring for now.")
+				} else {
+					a.c.Log.Info("Trust Bandle and Server dont agree.... rebootstrapping")
+					err = a.c.TrustBundleSources.SetForceRebootstrap()
+					if err != nil {
+						return nil, err
+					}
+					return nil, errors.New("Agent needs to rebootstrap. shutting down")
+				}
+			}
 
 			if nodeutil.ShouldAgentReattest(err) || nodeutil.ShouldAgentShutdown(err) {
 				return nil, err
@@ -412,13 +516,14 @@ func (a *Agent) CheckHealth() health.State {
 	// for the X509SVID service.
 	// TODO: Better live check for agent.
 	return health.State{
-		Ready: err == nil,
-		Live:  err == nil,
+		Started: &a.started,
+		Ready:   err == nil,
+		Live:    (!a.started || err == nil),
 		ReadyDetails: agentHealthDetails{
-			WorkloadAPIErr: errString(err),
+			WorkloadAPIErr: errString(false, err),
 		},
 		LiveDetails: agentHealthDetails{
-			WorkloadAPIErr: errString(err),
+			WorkloadAPIErr: errString(!a.started, err),
 		},
 	}
 }
@@ -442,9 +547,22 @@ type agentHealthDetails struct {
 	WorkloadAPIErr string `json:"make_new_x509_err,omitempty"`
 }
 
-func errString(err error) string {
+func errString(suppress bool, err error) string {
+	if suppress {
+		return ""
+	}
 	if err != nil {
 		return err.Error()
 	}
 	return ""
 }
+
+func (a *Agent) startHealthChecks(readyForHealthChecks chan struct{}, taskRunner *util.TaskRunner, healthChecker health.ServableChecker) {
+	select {
+	case <-readyForHealthChecks:
+		// Endpoints are ready for health checks, proceed with health checks.
+	case <-time.After(startHealthChecksTimeout):
+		// Timeout waiting for endpoints to start listening.
+	}
+	taskRunner.StartTasks(healthChecker.ListenAndServe)
+}
