@@ -20,7 +20,10 @@ func (a PeerTrackerAttestor) Attest(ctx context.Context) ([]*common.Selector, er
 		return nil, status.Error(codes.Internal, "peer tracker watcher missing from context")
 	}
 
-	selectors := a.Attestor.Attest(ctx, int(watcher.PID()))
+	selectors, err := a.Attestor.Attest(ctx, int(watcher.PID()))
+	if err != nil {
+		return nil, err
+	}
 
 	// Ensure that the original caller is still alive so that we know we didn't
 	// attest some other process that happened to be assigned the original PID
