@@ -29,6 +29,7 @@ import (
 	"github.com/spiffe/spire/pkg/agent/manager/storecache"
 	"github.com/spiffe/spire/pkg/agent/plugin/keymanager"
 	"github.com/spiffe/spire/pkg/agent/storage"
+	"github.com/spiffe/spire/pkg/agent/trustbundlesources"
 	"github.com/spiffe/spire/pkg/agent/workloadkey"
 	"github.com/spiffe/spire/pkg/common/bundleutil"
 	"github.com/spiffe/spire/pkg/common/idutil"
@@ -76,16 +77,34 @@ func TestInitializationFailure(t *testing.T) {
 	cat := fakeagentcatalog.New()
 	cat.SetKeyManager(km)
 
+	sto := openStorage(t, dir)
+	ts := &trustbundlesources.Config{
+		InsecureBootstrap:     false,
+		TrustBundleFormat:     "pem",
+		TrustBundlePath:       "",
+		TrustBundleURL:        "",
+		TrustBundleUnixSocket: "",
+		TrustDomain:           "example.org",
+		ServerAddress:         "localhost",
+		ServerPort:            1234,
+	}
+
+	tbs := trustbundlesources.New(ts, nil)
+	tbs.SetMetrics(&telemetry.Blackhole{})
+	err := tbs.SetStorage(sto)
+	require.NoError(t, err)
+
 	c := &Config{
-		SVID:           baseSVID,
-		SVIDKey:        baseSVIDKey,
-		Log:            testLogger,
-		Metrics:        &telemetry.Blackhole{},
-		TrustDomain:    trustDomain,
-		Storage:        openStorage(t, dir),
-		Clk:            clk,
-		Catalog:        cat,
-		SVIDStoreCache: storecache.New(&storecache.Config{TrustDomain: trustDomain, Log: testLogger}),
+		SVID:               baseSVID,
+		SVIDKey:            baseSVIDKey,
+		Log:                testLogger,
+		Metrics:            &telemetry.Blackhole{},
+		TrustDomain:        trustDomain,
+		TrustBundleSources: tbs,
+		Storage:            sto,
+		Clk:                clk,
+		Catalog:            cat,
+		SVIDStoreCache:     storecache.New(&storecache.Config{TrustDomain: trustDomain, Log: testLogger}),
 	}
 	m := newManager(c)
 	require.Error(t, m.Initialize(context.Background()))
@@ -375,7 +394,7 @@ func TestSVIDRotation(t *testing.T) {
 
 	clk := clock.NewMock(t)
 
-	baseTTL := 3
+	baseTTLSeconds := 3
 	api := newMockAPI(t, &mockAPIConfig{
 		km: km,
 		getAuthorizedEntries: func(*mockAPI, int32, *entryv1.GetAuthorizedEntriesRequest) (*entryv1.GetAuthorizedEntriesResponse, error) {
@@ -384,12 +403,12 @@ func TestSVIDRotation(t *testing.T) {
 		batchNewX509SVIDEntries: func(*mockAPI, int32) []*common.RegistrationEntry {
 			return makeBatchNewX509SVIDEntries("resp1", "resp2")
 		},
-		svidTTL: baseTTL,
+		svidTTL: baseTTLSeconds,
 		clk:     clk,
 	})
 
-	baseTTLSeconds := time.Duration(baseTTL) * time.Second
-	baseSVID, baseSVIDKey := api.newSVID(joinTokenID, baseTTLSeconds)
+	baseTTL := time.Duration(baseTTLSeconds) * time.Second
+	baseSVID, baseSVIDKey := api.newSVID(joinTokenID, baseTTL)
 
 	cat := fakeagentcatalog.New()
 	cat.SetKeyManager(km)
@@ -404,7 +423,7 @@ func TestSVIDRotation(t *testing.T) {
 		Storage:          openStorage(t, dir),
 		Bundle:           api.bundle,
 		Metrics:          &telemetry.Blackhole{},
-		RotationInterval: baseTTLSeconds / 2,
+		RotationInterval: baseTTL / 2,
 		SyncInterval:     1 * time.Hour,
 		Clk:              clk,
 		WorkloadKeyType:  workloadkey.ECP256,
@@ -449,7 +468,7 @@ func TestSVIDRotation(t *testing.T) {
 	// Now advance time enough that the cert is expiring soon enough that the
 	// manager will attempt to rotate, but be unable to since the read lock is
 	// held.
-	clk.Add(baseTTLSeconds)
+	clk.Add(baseTTL)
 
 	closer := runManager(t, m)
 	defer closer()
@@ -467,13 +486,7 @@ func TestSVIDRotation(t *testing.T) {
 	m.GetRotationMtx().RUnlock()
 
 	// Loop until we detect an SVID rotation was called in separate process
-	util.RunWithTimeout(t, time.Minute, func() {
-		for {
-			if wasRotHookCalled() {
-				break
-			}
-		}
-	})
+	require.Eventually(t, wasRotHookCalled, time.Minute, 100*time.Millisecond)
 
 	s := m.GetCurrentCredentials()
 	svid = s.SVID
@@ -1192,16 +1205,34 @@ func TestSyncRetriesWithDefaultIntervalOnZeroSVIDSReturned(t *testing.T) {
 	cat := fakeagentcatalog.New()
 	cat.SetKeyManager(km)
 
+	sto := openStorage(t, dir)
+	ts := &trustbundlesources.Config{
+		InsecureBootstrap:     false,
+		TrustBundleFormat:     "pem",
+		TrustBundlePath:       "",
+		TrustBundleURL:        "",
+		TrustBundleUnixSocket: "",
+		TrustDomain:           "example.org",
+		ServerAddress:         "localhost",
+		ServerPort:            1234,
+	}
+
+	tbs := trustbundlesources.New(ts, nil)
+	tbs.SetMetrics(&telemetry.Blackhole{})
+	err := tbs.SetStorage(sto)
+	require.NoError(t, err)
+
 	c := &Config{
-		ServerAddr:       api.addr,
-		SVID:             baseSVID,
-		SVIDKey:          baseSVIDKey,
-		Log:              testLogger,
-		TrustDomain:      trustDomain,
-		Storage:          openStorage(t, dir),
-		Bundle:           api.bundle,
-		Metrics:          &telemetry.Blackhole{},
-		RotationInterval: time.Hour,
+		ServerAddr:         api.addr,
+		SVID:               baseSVID,
+		SVIDKey:            baseSVIDKey,
+		Log:                testLogger,
+		TrustDomain:        trustDomain,
+		TrustBundleSources: tbs,
+		Storage:            sto,
+		Bundle:             api.bundle,
+		Metrics:            &telemetry.Blackhole{},
+		RotationInterval:   time.Hour,
 		// set sync interval to a high value to proof that synchronizer retries sync
 		// with the lower default interval in case 0 entries are returned
 		SyncInterval:     time.Hour,
@@ -1280,16 +1311,37 @@ func TestSyncFailsWithUnknownAuthority(t *testing.T) {
 	cat := fakeagentcatalog.New()
 	cat.SetKeyManager(km)
 
+	sto := openStorage(t, dir)
+	ts := &trustbundlesources.Config{
+		InsecureBootstrap:     false,
+		TrustBundleFormat:     "pem",
+		TrustBundlePath:       "",
+		TrustBundleURL:        "",
+		TrustBundleUnixSocket: "",
+		TrustDomain:           "example.org",
+		ServerAddress:         "localhost",
+		ServerPort:            1234,
+	}
+
+	tbs := trustbundlesources.New(ts, nil)
+	tbs.SetMetrics(&telemetry.Blackhole{})
+	err := tbs.SetStorage(sto)
+	require.NoError(t, err)
+
+	rebootstrapDelay, _ := time.ParseDuration("10m")
 	c := &Config{
-		ServerAddr:       api.addr,
-		SVID:             baseSVID,
-		SVIDKey:          baseSVIDKey,
-		Log:              testLogger,
-		TrustDomain:      trustDomain,
-		Storage:          openStorage(t, dir),
-		Bundle:           api.bundle,
-		Metrics:          &telemetry.Blackhole{},
-		RotationInterval: time.Hour,
+		ServerAddr:         api.addr,
+		SVID:               baseSVID,
+		SVIDKey:            baseSVIDKey,
+		Log:                testLogger,
+		TrustDomain:        trustDomain,
+		TrustBundleSources: tbs,
+		RebootstrapMode:    "never",
+		RebootstrapDelay:   rebootstrapDelay,
+		Storage:            sto,
+		Bundle:             api.bundle,
+		Metrics:            &telemetry.Blackhole{},
+		RotationInterval:   time.Hour,
 		// set sync interval to a high value to proof that synchronizer retries sync
 		// with the lower default interval in case 0 entries are returned
 		SyncInterval:     time.Hour,
@@ -1308,7 +1360,7 @@ func TestSyncFailsWithUnknownAuthority(t *testing.T) {
 	}
 
 	/// Sync to get expected error
-	err := m.runSynchronizer(ctx)
+	err = m.runSynchronizer(ctx)
 	spiretest.RequireErrorPrefix(t, err, "failed to sync with SPIRE Server:")
 }
 
@@ -1419,7 +1471,7 @@ func TestSurvivesCARotation(t *testing.T) {
 	km := fakeagentkeymanager.New(t, dir)
 
 	clk := clock.NewMock(t)
-	ttl := 3
+	ttlSeconds := 3
 	api := newMockAPI(t, &mockAPIConfig{
 		km: km,
 		getAuthorizedEntries: func(h *mockAPI, count int32, req *entryv1.GetAuthorizedEntriesRequest) (*entryv1.GetAuthorizedEntriesResponse, error) {
@@ -1432,15 +1484,15 @@ func TestSurvivesCARotation(t *testing.T) {
 		clk: clk,
 		// Give a low ttl to get expired entries on each synchronization, forcing
 		// the manager to fetch entries from the server.
-		svidTTL: ttl,
+		svidTTL: ttlSeconds,
 	})
 
 	baseSVID, baseSVIDKey := api.newSVID(joinTokenID, 1*time.Hour)
 	cat := fakeagentcatalog.New()
 	cat.SetKeyManager(km)
 
-	ttlSeconds := time.Duration(ttl) * time.Second
-	syncInterval := ttlSeconds / 2
+	ttl := time.Duration(ttlSeconds) * time.Second
+	syncInterval := ttl / 2
 	c := &Config{
 		ServerAddr:       api.addr,
 		SVID:             baseSVID,
