@@ -24,7 +24,6 @@ import (
 	"github.com/spiffe/spire/pkg/agent/client"
 	"github.com/spiffe/spire/pkg/agent/manager/cache"
 	"github.com/spiffe/spire/pkg/agent/plugin/keymanager"
-	"github.com/spiffe/spire/pkg/common/fflag"
 	"github.com/spiffe/spire/pkg/common/idutil"
 	"github.com/spiffe/spire/pkg/common/rotationutil"
 	"github.com/spiffe/spire/pkg/common/telemetry"
@@ -48,13 +47,6 @@ var (
 	testTimeout    = time.Minute
 )
 
-func init() {
-	err := fflag.Load(fflag.RawConfig{"reattest_to_renew"})
-	if err != nil {
-		panic(err)
-	}
-}
-
 func TestRotator(t *testing.T) {
 	caCert, caKey := testca.CreateCACertificate(t, nil, nil)
 	serverCert, serverKey := testca.CreateX509Certificate(t, caCert, caKey, testca.WithID(idutil.RequireServerID(trustDomain)))
@@ -70,10 +62,11 @@ func TestRotator(t *testing.T) {
 	}
 
 	for _, tt := range []struct {
-		name         string
-		notAfter     time.Duration
-		shouldRotate bool
-		reattest     bool
+		name          string
+		notAfter      time.Duration
+		shouldRotate  bool
+		reattest      bool
+		forceRotation bool
 	}{
 		{
 			name:         "not expired at startup",
@@ -102,6 +95,13 @@ func TestRotator(t *testing.T) {
 			shouldRotate: true,
 			reattest:     true,
 		},
+		{
+			name:          "reattest when requested",
+			notAfter:      time.Minute,
+			shouldRotate:  false,
+			reattest:      true,
+			forceRotation: true,
+		},
 	} {
 		t.Run(tt.name, func(t *testing.T) {
 			svidKM := keymanager.ForSVID(fakeagentkeymanager.New(t, ""))
@@ -120,7 +120,9 @@ func TestRotator(t *testing.T) {
 			// Create the starting SVID
 			svidKey, err := svidKM.GenerateKey(context.Background(), nil)
 			require.NoError(t, err)
+
 			svid, err := createTestSVID(svidKey.Public(), caCert, caKey, clk.Now(), clk.Now().Add(tt.notAfter))
+
 			require.NoError(t, err)
 
 			// Advance the clock by one second so SVID will always be expired
@@ -156,6 +158,7 @@ func TestRotator(t *testing.T) {
 				RotationStrategy: rotationutil.NewRotationStrategy(0),
 			})
 			rotator.client = mockClient
+			rotator.hooks.runRotatorSignal = make(chan struct{})
 
 			// Hook the rotation loop so we can determine when the rotator
 			// has finished a rotation evaluation (does not imply anything
@@ -177,6 +180,9 @@ func TestRotator(t *testing.T) {
 				errCh <- rotator.Run(ctx)
 			}()
 
+			// Make sure that the rotator is running
+			<-rotator.hooks.runRotatorSignal
+
 			// All tests should get through one rotation loop or error
 			select {
 			case <-clk.WaitForAfterCh():
@@ -208,6 +214,9 @@ func TestRotator(t *testing.T) {
 					}
 					t.Fatal("timed out waiting for rotation check to finish")
 				}
+			} else if tt.forceRotation {
+				err := rotator.Reattest(context.Background())
+				require.NoError(t, err)
 			}
 
 			// Shut down the rotator
@@ -221,7 +230,7 @@ func TestRotator(t *testing.T) {
 
 			// If rotation was supposed to happen, wait for the SVID changes
 			// on the state stream.
-			if tt.shouldRotate {
+			if tt.shouldRotate || tt.forceRotation {
 				require.True(t, stream.HasNext(), "SVID stream should have changes")
 				stream.Next()
 			} else {
@@ -232,7 +241,7 @@ func TestRotator(t *testing.T) {
 			// the appropriate number of times.
 			state := stream.Value().(State)
 			require.Len(t, state.SVID, 1)
-			if tt.shouldRotate {
+			if tt.shouldRotate || tt.forceRotation {
 				assert.NotEqual(t, svid, state.SVID)
 				assert.NotEqual(t, svidKey, state.Key)
 				assert.Equal(t, 2, mockClient.releaseCount, "client might not released after rotation")
@@ -378,6 +387,163 @@ func TestRotationFails(t *testing.T) {
 	}
 }
 
+func TestNotifyTaintedAuthority(t *testing.T) {
+	caCert, caKey := testca.CreateCACertificate(t, nil, nil)
+	anotherCert, _ := testca.CreateCACertificate(t, nil, nil)
+
+	svidKM := keymanager.ForSVID(fakeagentkeymanager.New(t, ""))
+	clk := clock.NewMock(t)
+	log, logHook := test.NewNullLogger()
+	log.Level = logrus.DebugLevel
+
+	mockClient := &fakeClient{
+		clk:    clk,
+		caCert: caCert,
+		caKey:  caKey,
+	}
+
+	// Create the bundle
+	bundle := make(map[spiffeid.TrustDomain]*spiffebundle.Bundle)
+	bundle[trustDomain] = spiffebundle.FromX509Authorities(trustDomain, []*x509.Certificate{caCert})
+
+	// Create the starting SVID
+	svidKey, err := svidKM.GenerateKey(context.Background(), nil)
+	require.NoError(t, err)
+
+	svid, err := createTestSVID(svidKey.Public(), caCert, caKey, clk.Now(), clk.Now().Add(time.Minute))
+	require.NoError(t, err)
+
+	// Initialize the rotator
+	rotator, _ := newRotator(&RotatorConfig{
+		SVIDKeyManager:   svidKM,
+		Log:              log,
+		Metrics:          telemetry.Blackhole{},
+		TrustDomain:      trustDomain,
+		BundleStream:     cache.NewBundleStream(observer.NewProperty(bundle).Observe()),
+		Clk:              clk,
+		SVID:             svid,
+		SVIDKey:          svidKey,
+		NodeAttestor:     fakeagentnodeattestor.New(t, fakeagentnodeattestor.Config{}),
+		RotationStrategy: rotationutil.NewRotationStrategy(0),
+	})
+	rotator.client = mockClient
+
+	// Ensure cert is not tainted initially
+	require.False(t, rotator.IsTainted())
+
+	for _, tt := range []struct {
+		name        string
+		authorities []*x509.Certificate
+
+		expectTainted bool
+		expectLogs    []spiretest.LogEntry
+	}{
+		{
+			name:          "no tainted",
+			authorities:   []*x509.Certificate{anotherCert},
+			expectTainted: false,
+		},
+		{
+			name:          "taint successfully",
+			authorities:   []*x509.Certificate{caCert},
+			expectTainted: true,
+			expectLogs: []spiretest.LogEntry{
+				{
+					Level:   logrus.InfoLevel,
+					Message: "Agent SVID is tainted by a root authority, forcing rotation",
+				},
+			},
+		},
+		{
+			name:          "already tainted",
+			authorities:   []*x509.Certificate{caCert},
+			expectTainted: true,
+			expectLogs: []spiretest.LogEntry{
+				{
+					Level:   logrus.DebugLevel,
+					Message: "Agent SVID already tainted",
+				},
+			},
+		},
+	} {
+		t.Run(tt.name, func(t *testing.T) {
+			logHook.Reset()
+
+			err := rotator.NotifyTaintedAuthorities(tt.authorities)
+			require.NoError(t, err)
+
+			assert.Equal(t, tt.expectTainted, rotator.IsTainted())
+			spiretest.AssertLogs(t, logHook.AllEntries(), tt.expectLogs)
+		})
+	}
+}
+
+func TestTaintedSVIDIsRotated(t *testing.T) {
+	caCert, caKey := testca.CreateCACertificate(t, nil, nil)
+
+	svidKM := keymanager.ForSVID(fakeagentkeymanager.New(t, ""))
+	clk := clock.NewMock(t)
+	log, _ := test.NewNullLogger()
+
+	mockClient := &fakeClient{
+		clk:    clk,
+		caCert: caCert,
+		caKey:  caKey,
+	}
+
+	// Create the bundle
+	bundle := make(map[spiffeid.TrustDomain]*spiffebundle.Bundle)
+	bundle[trustDomain] = spiffebundle.FromX509Authorities(trustDomain, []*x509.Certificate{caCert})
+
+	// Create the starting SVID
+	svidKey, err := svidKM.GenerateKey(context.Background(), nil)
+	require.NoError(t, err)
+
+	svid, err := createTestSVID(svidKey.Public(), caCert, caKey, clk.Now(), clk.Now().Add(time.Minute))
+	require.NoError(t, err)
+
+	// Initialize the rotator
+	rotator, _ := newRotator(&RotatorConfig{
+		SVIDKeyManager:   svidKM,
+		Log:              log,
+		Metrics:          telemetry.Blackhole{},
+		TrustDomain:      trustDomain,
+		BundleStream:     cache.NewBundleStream(observer.NewProperty(bundle).Observe()),
+		Clk:              clk,
+		SVID:             svid,
+		SVIDKey:          svidKey,
+		NodeAttestor:     fakeagentnodeattestor.New(t, fakeagentnodeattestor.Config{}),
+		RotationStrategy: rotationutil.NewRotationStrategy(0),
+	})
+	rotator.client = mockClient
+	rotationFinishedCh := make(chan struct{}, 1)
+	rotator.hooks.rotationFinishedHook = func() {
+		close(rotationFinishedCh)
+	}
+
+	// Mark SVID as tainted
+	rotator.tainted = true
+
+	ctx, cancel := context.WithTimeout(context.Background(), time.Minute)
+	defer cancel()
+
+	errCh := make(chan error)
+	go func() {
+		errCh <- rotator.Run(ctx)
+	}()
+
+	select {
+	case err = <-errCh:
+		t.Fatalf("unexpected error during first rotation loop: %v", err)
+	case <-rotationFinishedCh:
+		// Rotation expected
+	case <-ctx.Done():
+		t.Fatal("expected rotation to finish before timeout")
+	}
+
+	require.False(t, rotator.IsTainted(), "SVID must not be tainted after rotation")
+}
+
 type fakeClient struct {
 	clk          clock.Clock
 	caCert       *x509.Certificate
