@@ -11,6 +11,9 @@ import (
 	"testing"
 
 	"github.com/sirupsen/logrus/hooks/test"
+	"github.com/spiffe/spire/pkg/agent/storage"
+	"github.com/spiffe/spire/pkg/common/telemetry"
+	"github.com/spiffe/spire/test/spiretest"
 	"github.com/spiffe/spire/test/util"
 	"github.com/stretchr/testify/require"
 )
@@ -85,7 +88,7 @@ func TestGetBundle(t *testing.T) {
 	for _, testCase := range cases {
 		t.Run(testCase.msg, func(t *testing.T) {
 			var err error
-			var c Config = Config{
+			c := Config{
 				InsecureBootstrap:     testCase.insecureBootstrap,
 				TrustBundlePath:       testCase.trustBundlePath,
 				TrustBundleFormat:     testCase.trustBundleFormat,
@@ -101,6 +104,10 @@ func TestGetBundle(t *testing.T) {
 			}
 			log, _ := test.NewNullLogger()
 			tbs := New(&c, log)
+			dir := spiretest.TempDir(t)
+			sto := openStorage(t, dir)
+			tbs.SetMetrics(&telemetry.Blackhole{})
+			err = tbs.SetStorage(sto)
 			require.NoError(t, err)
 
 			trustBundle, insecureBootstrap, err := tbs.GetBundle()
@@ -260,3 +267,9 @@ func TestDownloadTrustBundle(t *testing.T) {
 		})
 	}
 }
+
+func openStorage(t *testing.T, dir string) storage.Storage {
+	sto, err := storage.Open(dir)
+	require.NoError(t, err)
+	return sto
+}
