@@ -3,6 +3,9 @@ package trustbundlesources
 const (
 	BundleFormatPEM    = "pem"
 	BundleFormatSPIFFE = "spiffe"
+	UseUnspecified     = 0
+	UseBootstrap       = 1
+	UseRebootstrap     = 2
 )
 
 type Config struct {
@@ -11,4 +14,7 @@ type Config struct {
 	TrustBundlePath       string
 	TrustBundleURL        string
 	TrustBundleUnixSocket string
+	TrustDomain           string
+	ServerAddress         string
+	ServerPort            int
 }
