@@ -4,26 +4,10 @@ import (
 	"crypto/sha256"
 	"encoding/hex"
 	"fmt"
-	"hash"
 	"io"
 	"os"
-
-	"github.com/spiffe/spire/proto/spire/common"
 )
 
-func DeriveRegEntryhash(entry *common.RegistrationEntry) (key string) {
-	var concatSelectors string
-	SortSelectors(entry.Selectors)
-
-	for _, selector := range entry.Selectors {
-		concatSelectors = concatSelectors + "::" + selector.Type + ":" + selector.Value
-	}
-
-	hashValue := hash.Hash.Sum(sha256.New(), []byte(concatSelectors+entry.SpiffeId+entry.ParentId))
-
-	return hex.EncodeToString(hashValue)
-}
-
 // GetSHA256Digest calculates the sha256 digest of a file specified by path. If the size of the file exceeds the provided
 // limit, the hash will not be calculated and an error will be returned instead.
 func GetSHA256Digest(path string, limit int64) (string, error) {
