@@ -7,8 +7,6 @@ import (
 	"crypto/x509"
 	"errors"
 	"fmt"
-	"os"
-	"path/filepath"
 	"time"
 
 	"github.com/sirupsen/logrus"
@@ -19,7 +17,6 @@ import (
 	"github.com/spiffe/spire/pkg/server/catalog"
 	"github.com/spiffe/spire/proto/private/server/journal"
 	"github.com/spiffe/spire/proto/spire/common"
-	"github.com/zeebo/errs"
 	"google.golang.org/grpc/codes"
 	"google.golang.org/grpc/status"
 )
@@ -111,10 +108,6 @@ func (s *SlotLoader) load(ctx context.Context) (*Journal, map[SlotPosition]Slot,
 		slots[NextJWTKeySlot] = nextJWTKey
 	}
 
-	// TODO: Remove after 1.11.0 release.
-	// No point in checking for errors here, we're just trying to clean up the
-	// CA journal file that was used before 1.9.0.
-	os.Remove(s.journalPath())
 	return loadedJournal, slots, nil
 }
 
@@ -148,17 +141,6 @@ func (s *SlotLoader) getX509CASlots(ctx context.Context, entries []*journal.X509
 		case journal.Status_ACTIVE:
 			current = slot
 
-		// Status can be UNKNOWN only after an upgrade when this happens,
-		// we must first set next position, and then current is the next one
-		// TODO: status in journal has been introduced in v1.7.
-		// Keep this validation in v1.7.x and v1.8.x. Remove this in v1.9.
-		case journal.Status_UNKNOWN:
-			if next == nil {
-				next = slot
-			} else if current == nil {
-				current = slot
-			}
-
 		// Set OLD or PREPARED as next slot
 		// Get the newest, since Prepared entry must always be located before an Old entry
 		default:
@@ -221,17 +203,6 @@ func (s *SlotLoader) getJWTKeysSlots(ctx context.Context, entries []*journal.JWT
 		case journal.Status_ACTIVE:
 			current = slot
 
-		// Status can be UNKNOWN only after an upgrade when this happens,
-		// we must first set next position, and then current is the next one
-		// TODO: status in journal has been introduced in v1.7.
-		// Keep this validation in v1.7.x and v1.8.x. Remove this in v1.9.
-		case journal.Status_UNKNOWN:
-			if next == nil {
-				next = slot
-			} else if current == nil {
-				current = slot
-			}
-
 		// Set OLD or PREPARED as next slot
 		// Get the newest, since Prepared entry must always be located before an Old entry
 		default:
@@ -274,7 +245,6 @@ func (s *SlotLoader) getJWTKeysSlots(ctx context.Context, entries []*journal.JWT
 // Instead, we'll rotate into a new one.
 func (s *SlotLoader) filterInvalidEntries(ctx context.Context, entries *journal.Entries) ([]*journal.JWTKeyEntry, []*journal.X509CAEntry, error) {
 	bundle, err := s.fetchOptionalBundle(ctx)
-
 	if err != nil {
 		return nil, nil, err
 	}
@@ -314,7 +284,7 @@ func (s *SlotLoader) fetchOptionalBundle(ctx context.Context) (*common.Bundle, e
 	ds := s.Catalog.GetDataStore()
 	bundle, err := ds.FetchBundle(ctx, s.TrustDomain.IDString())
 	if err != nil {
-		return nil, errs.Wrap(err)
+		return nil, err
 	}
 	return bundle, nil
 }
@@ -349,16 +319,20 @@ func (s *SlotLoader) loadX509CASlotFromEntry(ctx context.Context, entry *journal
 		return nil, "no slot id", nil
 	}
 
+	if entry.GetNotAfter() < time.Now().Unix() {
+		return nil, "slot expired", nil
+	}
+
 	cert, err := x509.ParseCertificate(entry.Certificate)
 	if err != nil {
-		return nil, "", errs.New("unable to parse CA certificate: %v", err)
+		return nil, "", fmt.Errorf("unable to parse CA certificate: %w", err)
 	}
 
 	var upstreamChain []*x509.Certificate
 	for _, certDER := range entry.UpstreamChain {
 		cert, err := x509.ParseCertificate(certDER)
 		if err != nil {
-			return nil, "", errs.New("unable to parse upstream chain certificate: %v", err)
+			return nil, "", fmt.Errorf("unable to parse upstream chain certificate: %w", err)
 		}
 		upstreamChain = append(upstreamChain, cert)
 	}
@@ -419,9 +393,13 @@ func (s *SlotLoader) loadJWTKeySlotFromEntry(ctx context.Context, entry *journal
 		return nil, "no slot id", nil
 	}
 
+	if entry.GetNotAfter() < time.Now().Unix() {
+		return nil, "slot expired", nil
+	}
+
 	publicKey, err := x509.ParsePKIXPublicKey(entry.PublicKey)
 	if err != nil {
-		return nil, "", errs.Wrap(err)
+		return nil, "", err
 	}
 
 	signer, err := s.makeSigner(ctx, jwtKeyKmKeyID(entry.SlotId))
@@ -460,14 +438,10 @@ func (s *SlotLoader) makeSigner(ctx context.Context, keyID string) (crypto.Signe
 	case codes.NotFound:
 		return nil, nil
 	default:
-		return nil, errs.Wrap(err)
+		return nil, err
 	}
 }
 
-func (s *SlotLoader) journalPath() string {
-	return filepath.Join(s.Dir, "journal.pem")
-}
-
 func x509CAKmKeyID(id string) string {
 	return fmt.Sprintf("x509-CA-%s", id)
 }
@@ -512,19 +486,13 @@ func otherSlotID(id string) string {
 
 func preparationThreshold(issuedAt, notAfter time.Time) time.Time {
 	lifetime := notAfter.Sub(issuedAt)
-	threshold := lifetime / preparationThresholdDivisor
-	if threshold > preparationThresholdCap {
-		threshold = preparationThresholdCap
-	}
+	threshold := min(lifetime/preparationThresholdDivisor, preparationThresholdCap)
 	return notAfter.Add(-threshold)
 }
 
 func keyActivationThreshold(issuedAt, notAfter time.Time) time.Time {
 	lifetime := notAfter.Sub(issuedAt)
-	threshold := lifetime / activationThresholdDivisor
-	if threshold > activationThresholdCap {
-		threshold = activationThresholdCap
-	}
+	threshold := min(lifetime/activationThresholdDivisor, activationThresholdCap)
 	return notAfter.Add(-threshold)
 }
 
