@@ -228,8 +228,10 @@ func TestJournalLoad(t *testing.T) {
 				X509CAs: []*journal.X509CAEntry{
 					{
 						SlotId:      "B",
+						NotAfter:    notAfterUnix,
 						IssuedAt:    secondIssuedAtUnix,
 						Certificate: x509RootB.Raw,
+						Status:      journal.Status_ACTIVE,
 					},
 				},
 				JwtKeys: []*journal.JWTKeyEntry{
@@ -239,6 +241,7 @@ func TestJournalLoad(t *testing.T) {
 						Kid:       "kid2",
 						NotAfter:  notAfterUnix,
 						PublicKey: jwtKeyBPKIX,
+						Status:    journal.Status_ACTIVE,
 					},
 				},
 			},
@@ -246,7 +249,7 @@ func TestJournalLoad(t *testing.T) {
 				CurrentX509CASlot: &x509CASlot{
 					id:       "B",
 					issuedAt: secondIssuedAt,
-					status:   journal.Status_UNKNOWN,
+					status:   journal.Status_ACTIVE,
 					x509CA: &ca.X509CA{
 						Signer:      x509KeyB,
 						Certificate: x509RootB,
@@ -259,7 +262,7 @@ func TestJournalLoad(t *testing.T) {
 				CurrentJWTKeySlot: &jwtKeySlot{
 					id:       "B",
 					issuedAt: secondIssuedAt,
-					status:   journal.Status_UNKNOWN,
+					status:   journal.Status_ACTIVE,
 					jwtKey: &ca.JWTKey{
 						Signer:   jwtKeyB,
 						Kid:      "kid2",
@@ -281,117 +284,6 @@ func TestJournalLoad(t *testing.T) {
 				},
 			},
 		},
-		{
-			name: "Stored entries has unknown status",
-			entries: &journal.Entries{
-				X509CAs: []*journal.X509CAEntry{
-					{
-						SlotId:      "A",
-						IssuedAt:    firstIssuedAtUnix,
-						Certificate: x509RootA.Raw,
-						AuthorityId: "3",
-					},
-					{
-						SlotId:      "B",
-						IssuedAt:    secondIssuedAtUnix,
-						Certificate: x509RootB.Raw,
-						AuthorityId: "2",
-					},
-					{
-						SlotId:      "A",
-						IssuedAt:    thirdIssuedAtUnix,
-						Certificate: x509RootA.Raw,
-						AuthorityId: "1",
-					},
-				},
-				JwtKeys: []*journal.JWTKeyEntry{
-					{
-						SlotId:      "A",
-						IssuedAt:    firstIssuedAtUnix,
-						Kid:         "kid1",
-						NotAfter:    notAfterUnix,
-						PublicKey:   jwtKeyAPKIX,
-						AuthorityId: "c",
-					},
-					{
-						SlotId:      "B",
-						IssuedAt:    secondIssuedAtUnix,
-						Kid:         "kid2",
-						NotAfter:    notAfterUnix,
-						PublicKey:   jwtKeyBPKIX,
-						AuthorityId: "b",
-					},
-					{
-						SlotId:      "A",
-						IssuedAt:    thirdIssuedAtUnix,
-						Kid:         "kid3",
-						NotAfter:    notAfterUnix,
-						PublicKey:   jwtKeyAPKIX,
-						AuthorityId: "a",
-					},
-				},
-			},
-			expectSlots: map[SlotPosition]Slot{
-				CurrentX509CASlot: &x509CASlot{
-					id:       "B",
-					issuedAt: secondIssuedAt,
-					status:   journal.Status_UNKNOWN,
-					x509CA: &ca.X509CA{
-						Signer:      x509KeyB,
-						Certificate: x509RootB,
-					},
-					publicKey:   x509KeyB.Public(),
-					authorityID: "2",
-					notAfter:    x509RootB.NotAfter,
-				},
-				NextX509CASlot: &x509CASlot{
-					id:       "A",
-					issuedAt: thirdIssuedAt,
-					status:   journal.Status_UNKNOWN,
-					x509CA: &ca.X509CA{
-						Signer:      x509KeyA,
-						Certificate: x509RootA,
-					},
-					publicKey:   x509KeyA.Public(),
-					authorityID: "1",
-					notAfter:    x509RootA.NotAfter,
-				},
-				CurrentJWTKeySlot: &jwtKeySlot{
-					id:       "B",
-					issuedAt: secondIssuedAt,
-					status:   journal.Status_UNKNOWN,
-					jwtKey: &ca.JWTKey{
-						Signer:   jwtKeyB,
-						Kid:      "kid2",
-						NotAfter: notAfter,
-					},
-					authorityID: "b",
-					notAfter:    notAfter,
-				},
-				NextJWTKeySlot: &jwtKeySlot{
-					id:       "A",
-					issuedAt: thirdIssuedAt,
-					status:   journal.Status_UNKNOWN,
-					jwtKey: &ca.JWTKey{
-						Signer:   jwtKeyA,
-						Kid:      "kid3",
-						NotAfter: notAfter,
-					},
-					authorityID: "a",
-					notAfter:    notAfter,
-				},
-			},
-			expectLogs: []spiretest.LogEntry{
-				{
-					Level:   logrus.InfoLevel,
-					Message: "Journal loaded",
-					Data: logrus.Fields{
-						telemetry.JWTKeys: "3",
-						telemetry.X509CAs: "3",
-					},
-				},
-			},
-		},
 		{
 			name: "Stored entry has a single Prepared entry",
 			entries: &journal.Entries{
@@ -399,6 +291,7 @@ func TestJournalLoad(t *testing.T) {
 					{
 						SlotId:      "A",
 						IssuedAt:    thirdIssuedAtUnix,
+						NotAfter:    notAfterUnix,
 						Certificate: x509RootA.Raw,
 						Status:      journal.Status_PREPARED,
 						AuthorityId: "1",
@@ -466,6 +359,7 @@ func TestJournalLoad(t *testing.T) {
 					{
 						SlotId:      "A",
 						IssuedAt:    firstIssuedAtUnix,
+						NotAfter:    notAfterUnix,
 						Certificate: x509RootA.Raw,
 						Status:      journal.Status_OLD,
 						AuthorityId: "3",
@@ -473,6 +367,7 @@ func TestJournalLoad(t *testing.T) {
 					{
 						SlotId:      "B",
 						IssuedAt:    secondIssuedAtUnix,
+						NotAfter:    notAfterUnix,
 						Certificate: x509RootB.Raw,
 						Status:      journal.Status_OLD,
 						AuthorityId: "2",
@@ -480,6 +375,7 @@ func TestJournalLoad(t *testing.T) {
 					{
 						SlotId:      "A",
 						IssuedAt:    thirdIssuedAtUnix,
+						NotAfter:    notAfterUnix,
 						Certificate: x509RootA.Raw,
 						Status:      journal.Status_ACTIVE,
 						AuthorityId: "1",
@@ -584,6 +480,7 @@ func TestJournalLoad(t *testing.T) {
 					{
 						SlotId:      "A",
 						IssuedAt:    firstIssuedAtUnix,
+						NotAfter:    notAfterUnix,
 						Certificate: x509RootA.Raw,
 						Status:      journal.Status_ACTIVE,
 						AuthorityId: "3",
@@ -591,6 +488,7 @@ func TestJournalLoad(t *testing.T) {
 					{
 						SlotId:      "B",
 						IssuedAt:    secondIssuedAtUnix,
+						NotAfter:    notAfterUnix,
 						Certificate: x509RootB.Raw,
 						Status:      journal.Status_OLD,
 						AuthorityId: "2",
@@ -598,6 +496,7 @@ func TestJournalLoad(t *testing.T) {
 					{
 						SlotId:      "B",
 						IssuedAt:    thirdIssuedAtUnix,
+						NotAfter:    notAfterUnix,
 						Certificate: x509RootB.Raw,
 						Status:      journal.Status_PREPARED,
 						AuthorityId: "1",
@@ -702,6 +601,7 @@ func TestJournalLoad(t *testing.T) {
 					{
 						SlotId:              "A",
 						IssuedAt:            firstIssuedAtUnix,
+						NotAfter:            notAfterUnix,
 						Certificate:         []byte("foo"),
 						Status:              journal.Status_ACTIVE,
 						AuthorityId:         "1",
@@ -733,6 +633,50 @@ func TestJournalLoad(t *testing.T) {
 				},
 			},
 		},
+		{
+			name: "Expired X.509 entry",
+			entries: &journal.Entries{
+				X509CAs: []*journal.X509CAEntry{
+					{
+						SlotId:              "A",
+						IssuedAt:            firstIssuedAtUnix,
+						NotAfter:            time.Now().Add(-time.Minute).Unix(),
+						Certificate:         x509RootA.Raw,
+						Status:              journal.Status_ACTIVE,
+						AuthorityId:         "1",
+						UpstreamAuthorityId: "2",
+					},
+				},
+			},
+			expectSlots: map[SlotPosition]Slot{
+				CurrentX509CASlot: newX509CASlot("A"),
+				NextX509CASlot:    newX509CASlot("B"),
+				CurrentJWTKeySlot: newJWTKeySlot("A"),
+				NextJWTKeySlot:    newJWTKeySlot("B"),
+			},
+			expectLogs: []spiretest.LogEntry{
+				{
+					Level:   logrus.InfoLevel,
+					Message: "Journal loaded",
+					Data: logrus.Fields{
+						telemetry.X509CAs: "1",
+						telemetry.JWTKeys: "0",
+					},
+				},
+				{
+					Level:   logrus.WarnLevel,
+					Message: "X509CA slot unusable",
+					Data: logrus.Fields{
+						logrus.ErrorKey:               "slot expired",
+						telemetry.IssuedAt:            firstIssuedAt.String(),
+						telemetry.Slot:                "A",
+						telemetry.Status:              "ACTIVE",
+						telemetry.LocalAuthorityID:    "1",
+						telemetry.UpstreamAuthorityID: "2",
+					},
+				},
+			},
+		},
 		{
 			name: "Invalid JWTKey entry",
 			entries: &journal.Entries{
@@ -771,6 +715,49 @@ func TestJournalLoad(t *testing.T) {
 				},
 			},
 		},
+		{
+			name: "Expired JWTKey entry",
+			entries: &journal.Entries{
+				JwtKeys: []*journal.JWTKeyEntry{
+					{
+						SlotId:      "B",
+						IssuedAt:    thirdIssuedAtUnix,
+						Kid:         "kid3",
+						NotAfter:    time.Now().Add(-time.Minute).Unix(),
+						PublicKey:   jwtKeyAPKIX,
+						Status:      journal.Status_ACTIVE,
+						AuthorityId: "a",
+					},
+				},
+			},
+			expectSlots: map[SlotPosition]Slot{
+				CurrentX509CASlot: newX509CASlot("A"),
+				NextX509CASlot:    newX509CASlot("B"),
+				CurrentJWTKeySlot: newJWTKeySlot("A"),
+				NextJWTKeySlot:    newJWTKeySlot("B"),
+			},
+			expectLogs: []spiretest.LogEntry{
+				{
+					Level:   logrus.InfoLevel,
+					Message: "Journal loaded",
+					Data: logrus.Fields{
+						telemetry.X509CAs: "0",
+						telemetry.JWTKeys: "1",
+					},
+				},
+				{
+					Level:   logrus.WarnLevel,
+					Message: "JWT key slot unusable",
+					Data: logrus.Fields{
+						logrus.ErrorKey:            "slot expired",
+						telemetry.IssuedAt:         thirdIssuedAt.String(),
+						telemetry.Slot:             "B",
+						telemetry.Status:           "ACTIVE",
+						telemetry.LocalAuthorityID: "a",
+					},
+				},
+			},
+		},
 	} {
 		t.Run(tt.name, func(t *testing.T) {
 			loghook.Reset()
