@@ -37,7 +37,7 @@ func TestEntryIteratorDS(t *testing.T) {
 		{Type: "doesn't", Value: "matter"},
 	}
 	entriesToCreate := make([]*common.RegistrationEntry, numEntries)
-	for i := 0; i < numEntries; i++ {
+	for i := range numEntries {
 		entriesToCreate[i] = &common.RegistrationEntry{
 			ParentId:  parentID,
 			SpiffeId:  spiffeIDPrefix + strconv.Itoa(i),
@@ -57,7 +57,7 @@ func TestEntryIteratorDS(t *testing.T) {
 		it := makeEntryIteratorDS(ds)
 		var entries []*types.Entry
 
-		for i := 0; i < numEntries; i++ {
+		for range numEntries {
 			assert.True(t, it.Next(ctx))
 			require.NoError(t, it.Err())
 
@@ -73,7 +73,7 @@ func TestEntryIteratorDS(t *testing.T) {
 
 	t.Run("datastore error", func(t *testing.T) {
 		it := makeEntryIteratorDS(ds)
-		for i := 0; i < int(listEntriesRequestPageSize); i++ {
+		for range listEntriesRequestPageSize {
 			assert.True(t, it.Next(ctx))
 			require.NoError(t, it.Err())
 		}
@@ -105,7 +105,7 @@ func TestAgentIteratorDS(t *testing.T) {
 
 	expectedSelectors := api.ProtoFromSelectors(selectors)
 	expectedAgents := make([]Agent, numAgents)
-	for i := 0; i < numAgents; i++ {
+	for i := range numAgents {
 		iterStr := strconv.Itoa(i)
 		agentID, err := spiffeid.FromString("spiffe://example.org/spire/agent/agent" + iterStr)
 		require.NoError(t, err)
@@ -129,7 +129,7 @@ func TestAgentIteratorDS(t *testing.T) {
 	t.Run("multiple pages", func(t *testing.T) {
 		it := makeAgentIteratorDS(ds)
 		agents := make([]Agent, numAgents)
-		for i := 0; i < numAgents; i++ {
+		for i := range numAgents {
 			assert.True(t, it.Next(ctx))
 			assert.NoError(t, it.Err())
 			agents[i] = it.Agent()
