@@ -6,15 +6,21 @@ import (
 	"crypto/tls"
 	"crypto/x509"
 	"encoding/json"
+	"encoding/pem"
 	"errors"
 	"fmt"
+	"os"
 	"testing"
 
 	"github.com/spiffe/go-spiffe/v2/spiffeid"
+	identityproviderv1 "github.com/spiffe/spire-plugin-sdk/proto/spire/hostservice/server/identityprovider/v1"
+	plugintypes "github.com/spiffe/spire-plugin-sdk/proto/spire/plugin/types"
 	"github.com/spiffe/spire/pkg/common/catalog"
 	"github.com/spiffe/spire/pkg/common/plugin/x509pop"
+	spirecommonutil "github.com/spiffe/spire/pkg/common/util"
 	"github.com/spiffe/spire/pkg/server/plugin/nodeattestor"
 	"github.com/spiffe/spire/proto/spire/common"
+	"github.com/spiffe/spire/test/fakes/fakeidentityprovider"
 	"github.com/spiffe/spire/test/fixture"
 	"github.com/spiffe/spire/test/plugintest"
 	"github.com/spiffe/spire/test/spiretest"
@@ -36,6 +42,8 @@ type Suite struct {
 	leafCert         *x509.Certificate
 	intermediateCert *x509.Certificate
 	rootCert         *x509.Certificate
+	svidReg          [][]byte
+	svidExchange     [][]byte
 
 	alternativeBundlePath string
 	alternativeBundle     *x509.Certificate
@@ -47,6 +55,8 @@ func (s *Suite) SetupTest() {
 	s.rootCertPath = fixture.Join("nodeattestor", "x509pop", "root-crt.pem")
 	leafCertPath := fixture.Join("nodeattestor", "x509pop", "leaf-crt-bundle.pem")
 	leafKeyPath := fixture.Join("nodeattestor", "x509pop", "leaf-key.pem")
+	svidRegPath := fixture.Join("nodeattestor", "x509pop", "svidreg.pem")
+	svidExchangePath := fixture.Join("nodeattestor", "x509pop", "svidexchange.pem")
 
 	kp, err := tls.LoadX509KeyPair(leafCertPath, leafKeyPath)
 	require.NoError(err)
@@ -59,6 +69,15 @@ func (s *Suite) SetupTest() {
 	s.rootCert, err = util.LoadCert(s.rootCertPath)
 	require.NoError(err)
 
+	kp, err = tls.LoadX509KeyPair(svidRegPath, leafKeyPath)
+	require.NoError(err)
+	s.svidReg = kp.Certificate
+	require.NoError(err)
+
+	kp, err = tls.LoadX509KeyPair(svidExchangePath, leafKeyPath)
+	require.NoError(err)
+	s.svidExchange = kp.Certificate
+
 	// Add alternative bundle
 	s.alternativeBundlePath = fixture.Join("certs", "ca.pem")
 	s.alternativeBundle, err = util.LoadCert(s.alternativeBundlePath)
@@ -70,36 +89,59 @@ func (s *Suite) TestAttestSuccess() {
 		desc          string
 		giveConfig    string
 		expectAgentID string
+		certs         [][]byte
+		serialnumber  string
 	}{
 		{
 			desc:          "default success (ca_bundle_path)",
 			expectAgentID: "spiffe://example.org/spire/agent/x509pop/" + x509pop.Fingerprint(s.leafCert),
 			giveConfig:    s.createConfiguration("ca_bundle_path", ""),
+			certs:         s.leafBundle,
+			serialnumber:  "serialnumber:0a1b2c3d4e5f",
 		},
 		{
 			desc:          "success with custom agent id (ca_bundle_path)",
 			expectAgentID: "spiffe://example.org/spire/agent/cn/COMMONNAME",
 			giveConfig:    s.createConfiguration("ca_bundle_path", `agent_path_template = "/cn/{{ .Subject.CommonName }}"`),
+			certs:         s.leafBundle,
+			serialnumber:  "serialnumber:0a1b2c3d4e5f",
 		},
 		{
 			desc:          "default success (ca_bundle_paths)",
 			expectAgentID: "spiffe://example.org/spire/agent/x509pop/" + x509pop.Fingerprint(s.leafCert),
 			giveConfig:    s.createConfiguration("ca_bundle_path", ""),
+			certs:         s.leafBundle,
+			serialnumber:  "serialnumber:0a1b2c3d4e5f",
 		},
 		{
 			desc:          "success with custom agent id (ca_bundle_paths)",
 			expectAgentID: "spiffe://example.org/spire/agent/serialnumber/0a1b2c3d4e5f",
 			giveConfig:    s.createConfiguration("ca_bundle_paths", `agent_path_template = "/serialnumber/{{ .SerialNumberHex }}"`),
+			certs:         s.leafBundle,
+			serialnumber:  "serialnumber:0a1b2c3d4e5f",
+		},
+		{
+			desc:          "success with spiffe exchange",
+			expectAgentID: "spiffe://example.org/spire/agent/x509pop/testhost",
+			giveConfig:    s.createConfigurationModeSPIFFE(""),
+			certs:         s.svidExchange,
+			serialnumber:  "serialnumber:0a1b2c3d4e7f",
+		},
+		{
+			desc:          "success with custom X509pop san selectors",
+			expectAgentID: "spiffe://example.org/spire/agent/foo/us-east-1/production/path/to/value",
+			giveConfig:    s.createConfiguration("ca_bundle_paths", `agent_path_template = "/foo/{{ .URISanSelectors.datacenter }}/{{ .URISanSelectors.environment }}/{{ .URISanSelectors.key }}"`),
+			certs:         s.leafBundle,
+			serialnumber:  "serialnumber:0a1b2c3d4e5f",
 		},
 	}
 
 	for _, tt := range tests {
-		tt := tt // alias loop variable as it is used in the closure
 		s.T().Run(tt.desc, func(t *testing.T) {
 			attestor := s.loadPlugin(t, tt.giveConfig)
 
 			attestationData := &x509pop.AttestationData{
-				Certificates: s.leafBundle,
+				Certificates: tt.certs,
 			}
 			payload := marshal(t, attestationData)
 
@@ -119,19 +161,27 @@ func (s *Suite) TestAttestSuccess() {
 			require.NoError(t, err)
 			require.Equal(t, tt.expectAgentID, result.AgentID)
 
+			expectedSelectors := []*common.Selector{
+				{Type: "x509pop", Value: "subject:cn:COMMONNAME"},
+				{Type: "x509pop", Value: "ca:fingerprint:" + x509pop.Fingerprint(s.intermediateCert)},
+				{Type: "x509pop", Value: "ca:fingerprint:" + x509pop.Fingerprint(s.rootCert)},
+				{Type: "x509pop", Value: tt.serialnumber},
+				{Type: "x509pop", Value: "san:datacenter:us-east-1"},
+				{Type: "x509pop", Value: "san:environment:production"},
+				{Type: "x509pop", Value: "san:key:path/to/value"},
+			}
+			spirecommonutil.SortSelectors(expectedSelectors)
+			spirecommonutil.SortSelectors(result.Selectors)
+
 			spiretest.AssertProtoListEqual(t,
-				[]*common.Selector{
-					{Type: "x509pop", Value: "subject:cn:COMMONNAME"},
-					{Type: "x509pop", Value: "ca:fingerprint:" + x509pop.Fingerprint(s.intermediateCert)},
-					{Type: "x509pop", Value: "ca:fingerprint:" + x509pop.Fingerprint(s.rootCert)},
-					{Type: "x509pop", Value: "serialnumber:0a1b2c3d4e5f"},
-				}, result.Selectors)
+				expectedSelectors, result.Selectors)
 		})
 	}
 }
 
 func (s *Suite) TestAttestFailure() {
 	successConfiguration := s.createConfiguration("ca_bundle_path", "")
+	spiffeConfiguration := s.createConfigurationModeSPIFFE("")
 
 	makePayload := func(t *testing.T, attestationData *x509pop.AttestationData) []byte {
 		return marshal(t, attestationData)
@@ -144,13 +194,23 @@ func (s *Suite) TestAttestFailure() {
 		require.Nil(t, result)
 	}
 
-	challengeResponseFails := func(t *testing.T, attestor nodeattestor.NodeAttestor, challengeResp string, expectCode codes.Code, expectMessage string) {
+	challengeResponseFails := func(t *testing.T, attestor nodeattestor.NodeAttestor, certs [][]byte, challengeResp string, fullChallenge bool, expectCode codes.Code, expectMessage string) {
 		payload := makePayload(t, &x509pop.AttestationData{
-			Certificates: s.leafBundle,
+			Certificates: certs,
 		})
 		doChallenge := func(ctx context.Context, challenge []byte) ([]byte, error) {
 			return []byte(challengeResp), nil
 		}
+		if fullChallenge {
+			doChallenge = func(ctx context.Context, challenge []byte) ([]byte, error) {
+				require.NotEmpty(t, challenge)
+				popChallenge := new(x509pop.Challenge)
+				unmarshal(t, challenge, popChallenge)
+				response, err := x509pop.CalculateResponse(s.leafKey, popChallenge)
+				require.NoError(t, err)
+				return marshal(t, response), nil
+			}
+		}
 		result, err := attestor.Attest(context.Background(), payload, doChallenge)
 		spiretest.RequireGRPCStatusContains(t, err, expectCode, expectMessage)
 		require.Nil(t, result)
@@ -158,7 +218,9 @@ func (s *Suite) TestAttestFailure() {
 
 	s.T().Run("not configured", func(t *testing.T) {
 		attestor := new(nodeattestor.V1)
-		plugintest.Load(t, BuiltIn(), attestor)
+		plugintest.Load(t, BuiltIn(), attestor,
+			plugintest.HostServices(identityproviderv1.IdentityProviderServiceServer(fakeidentityprovider.New())),
+		)
 		attestFails(t, attestor, []byte("payload"), codes.FailedPrecondition,
 			"nodeattestor(x509pop): not configured")
 	})
@@ -203,12 +265,30 @@ func (s *Suite) TestAttestFailure() {
 
 	s.T().Run("malformed challenge response", func(t *testing.T) {
 		attestor := s.loadPlugin(t, successConfiguration)
-		challengeResponseFails(t, attestor, "", codes.InvalidArgument, "nodeattestor(x509pop): unable to unmarshal challenge response")
+		challengeResponseFails(t, attestor, s.leafBundle, "", false, codes.InvalidArgument, "nodeattestor(x509pop): unable to unmarshal challenge response")
 	})
 
 	s.T().Run("invalid response", func(t *testing.T) {
 		attestor := s.loadPlugin(t, successConfiguration)
-		challengeResponseFails(t, attestor, "{}", codes.PermissionDenied, "nodeattestor(x509pop): challenge response verification failed")
+		challengeResponseFails(t, attestor, s.leafBundle, "{}", false, codes.PermissionDenied, "nodeattestor(x509pop): challenge response verification failed")
+	})
+
+	s.T().Run("spiffe bad prefix", func(t *testing.T) {
+		attestor := s.loadPlugin(t, spiffeConfiguration)
+
+		challengeResponseFails(t, attestor, s.svidReg, "", true, codes.PermissionDenied, "nodeattestor(x509pop): x509 cert doesnt match SVID prefix")
+	})
+
+	s.T().Run("spiffe non svid", func(t *testing.T) {
+		attestor := s.loadPlugin(t, spiffeConfiguration)
+
+		challengeResponseFails(t, attestor, s.leafBundle, "", true, codes.PermissionDenied, "nodeattestor(x509pop): valid SVID x509 cert not found")
+	})
+
+	s.T().Run("spiffe non svid", func(t *testing.T) {
+		attestor := s.loadPluginFull(t, spiffeConfiguration, fakeidentityprovider.New())
+
+		challengeResponseFails(t, attestor, s.svidExchange, "", true, codes.Internal, "nodeattestor(x509pop): failed to get trust bundle")
 	})
 }
 
@@ -216,6 +296,7 @@ func (s *Suite) TestConfigure() {
 	doConfig := func(t *testing.T, coreConfig catalog.CoreConfig, config string) error {
 		var err error
 		plugintest.Load(t, BuiltIn(), nil,
+			plugintest.HostServices(identityproviderv1.IdentityProviderServiceServer(fakeidentityprovider.New())),
 			plugintest.CaptureConfigureError(&err),
 			plugintest.CoreConfig(coreConfig),
 			plugintest.Configure(config),
@@ -266,11 +347,51 @@ func (s *Suite) TestConfigure() {
 
 		spiretest.RequireGRPCStatusContains(t, err, codes.InvalidArgument, "unable to load trust bundle")
 	})
+
+	s.T().Run("bad mode and ca_bundle_paths", func(t *testing.T) {
+		err := doConfig(t, coreConfig, `
+		mode = "spiffe"
+		ca_bundle_paths = ["blah"]
+		`)
+
+		spiretest.RequireGRPCStatusContains(t, err, codes.InvalidArgument, "you can not use ca_bundle_path or ca_bundle_paths in spiffe mode")
+	})
+
+	s.T().Run("bad mode and ca_bundle_path", func(t *testing.T) {
+		err := doConfig(t, coreConfig, `
+		mode = "spiffe"
+		ca_bundle_path = "blah"
+		`)
+
+		spiretest.RequireGRPCStatusContains(t, err, codes.InvalidArgument, "you can not use ca_bundle_path or ca_bundle_paths in spiffe mode")
+	})
 }
 
 func (s *Suite) loadPlugin(t *testing.T, config string) nodeattestor.NodeAttestor {
+	return s.loadPluginFull(t, config, nil)
+}
+
+func (s *Suite) loadPluginFull(t *testing.T, config string, identityProvider *fakeidentityprovider.IdentityProvider) nodeattestor.NodeAttestor {
 	v1 := new(nodeattestor.V1)
+
+	if identityProvider == nil {
+		caRaw, err := os.ReadFile(s.rootCertPath)
+		if err != nil {
+			return nil
+		}
+		ca, _ := pem.Decode(caRaw)
+
+		bundle := &plugintypes.Bundle{
+			X509Authorities: []*plugintypes.X509Certificate{
+				{Asn1: ca.Bytes},
+			},
+		}
+
+		identityProvider = fakeidentityprovider.New()
+		identityProvider.AppendBundle(bundle)
+	}
 	plugintest.Load(t, BuiltIn(), v1,
+		plugintest.HostServices(identityproviderv1.IdentityProviderServiceServer(identityProvider)),
 		plugintest.CoreConfig(catalog.CoreConfig{
 			TrustDomain: spiffeid.RequireTrustDomainFromString("example.org"),
 		}),
@@ -301,6 +422,13 @@ ca_bundle_paths = %s
 	return ""
 }
 
+func (s *Suite) createConfigurationModeSPIFFE(extraConfig string) string {
+	return fmt.Sprintf(`
+mode = "spiffe"
+%s
+`, extraConfig)
+}
+
 func marshal(t *testing.T, obj any) []byte {
 	data, err := json.Marshal(obj)
 	require.NoError(t, err)
