@@ -16,7 +16,6 @@ import (
 	"github.com/spiffe/go-spiffe/v2/workloadapi"
 	"github.com/spiffe/spire/pkg/common/telemetry"
 	"github.com/spiffe/spire/pkg/common/util"
-	"github.com/zeebo/errs"
 )
 
 const (
@@ -56,19 +55,19 @@ func NewWorkloadAPISource(config WorkloadAPISourceConfig) (*WorkloadAPISource, e
 	if config.Addr != nil {
 		o, err := util.GetWorkloadAPIClientOption(config.Addr)
 		if err != nil {
-			return nil, errs.Wrap(err)
+			return nil, err
 		}
 		opts = append(opts, o)
 	}
 
 	trustDomain, err := spiffeid.TrustDomainFromString(config.TrustDomain)
 	if err != nil {
-		return nil, errs.Wrap(err)
+		return nil, err
 	}
 
 	client, err := workloadapi.New(context.Background(), opts...)
 	if err != nil {
-		return nil, errs.Wrap(err)
+		return nil, err
 	}
 
 	ctx, cancel := context.WithCancel(context.Background())
