@@ -53,32 +53,6 @@ func NewSVIDTemplate(clk clock.Clock, spiffeID string) (*x509.Certificate, error
 	return cert, err
 }
 
-func NewSVIDTemplateFromCSR(clk clock.Clock, csr []byte, ca *x509.Certificate, ttl int) (*x509.Certificate, error) {
-	cr, err := x509.ParseCertificateRequest(csr)
-	if err != nil {
-		return nil, err
-	}
-
-	now := clk.Now()
-	cert := &x509.Certificate{
-		Subject:            cr.Subject,
-		Issuer:             ca.Subject,
-		PublicKey:          cr.PublicKey,
-		PublicKeyAlgorithm: cr.PublicKeyAlgorithm,
-		Signature:          cr.Signature,
-		SignatureAlgorithm: cr.SignatureAlgorithm,
-		NotBefore:          now,
-		NotAfter:           now.Add(time.Duration(ttl) * time.Second),
-		KeyUsage: x509.KeyUsageKeyEncipherment |
-			x509.KeyUsageKeyAgreement |
-			x509.KeyUsageDigitalSignature,
-		ExtKeyUsage:           []x509.ExtKeyUsage{x509.ExtKeyUsageServerAuth, x509.ExtKeyUsageClientAuth},
-		BasicConstraintsValid: true,
-		ExtraExtensions:       cr.Extensions,
-	}
-	return cert, nil
-}
-
 // NewCATemplate returns a default CA template with the specified trust domain. Must
 // be signed before it's valid.
 func NewCATemplate(clk clock.Clock, trustDomain spiffeid.TrustDomain) (*x509.Certificate, error) {
